==> grpc_0.10.2.orig.tar.gz: grpc-0.10.2/src/objective-c/RxLibrary/GRXWriter+Immediate.m <==
/*
 *
 * Copyright 2015, Google Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#import "GRXWriter+Immediate.h"

#import "GRXImmediateWriter.h"

@implementation GRXWriter (Immediate)

+ (instancetype)writerWithEnumerator:(NSEnumerator *)enumerator {
  return [[self alloc] initWithWriter:[GRXImmediateWriter writerWithEnumerator:enumerator]];
}

+ (instancetype)writerWithValueSupplier:(id (^)())block {
  return [[self alloc] initWithWriter:[GRXImmediateWriter writerWithValueSupplier:block]];
}

+ (instancetype)writerWithContainer:(id<NSFastEnumeration>)container {
  return [[self alloc] initWithWriter:[GRXImmediateWriter writerWithContainer:container]];
}

+ (instancetype)writerWithValue:(id)value {
  return [[self alloc] initWithWriter:[GRXImmediateWriter writerWithValue:value]];
}

+ (instancetype)writerWithError:(NSError *)error {
  return [[self alloc] initWithWriter:[GRXImmediateWriter writerWithError:error]];
}

+ (instancetype)emptyWriter {
  return [[self alloc] initWithWriter:[GRXImmediateWriter emptyWriter]];
}

@end

==> grpc_0.11.1.orig.tar.gz: grpc-0.11.1/src/objective-c/RxLibrary/GRXWriter+Immediate.m <==
/*
 *
 * Copyright 2015, Google Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#import "GRXWriter+Immediate.h"

#import "GRXImmediateWriter.h"

@implementation GRXWriter (Immediate)

+ (instancetype)writerWithEnumerator:(NSEnumerator *)enumerator {
  return [GRXImmediateWriter writerWithEnumerator:enumerator];
}

+ (instancetype)writerWithValueSupplier:(id (^)())block {
  return [GRXImmediateWriter writerWithValueSupplier:block];
}

+ (instancetype)writerWithContainer:(id<NSFastEnumeration>)container {
  return [GRXImmediateWriter writerWithContainer:container];
}

+ (instancetype)writerWithValue:(id)value {
  return [GRXImmediateWriter writerWithValue:value];
}

+ (instancetype)writerWithError:(NSError *)error {
  return [GRXImmediateWriter writerWithError:error];
}

+ (instancetype)emptyWriter {
  return [GRXImmediateWriter emptyWriter];
}

@end
